import { computed, defineComponent, PropType, ref, watch } from 'vue';
import { UploadData } from '@/api/common';
import './index.scss';
import { BaseMediaUrl } from '@/constants/constants';

export default defineComponent({
  name: 'Preview',
  props: {
    dialog: Boolean,
    current: {
      type: Number,
      default: 0,
    },
    medias: {
      type: Array as PropType<(UploadData & { type: 'image' | 'video' })[]>,
      default: [],
    },
  },
  setup(props, ctx) {
    const currentMediaKey = ref(props.current);

    const currentMedia = computed(() => props.medias[currentMediaKey.value]);

    watch(
      () => props.current,
      (next) => (currentMediaKey.value = next),
    );

    const handlePreviewLeftBtn = () => {
      if (props.medias.length === 0) return;
      if (currentMediaKey.value - 1 < 0) {
        currentMediaKey.value = props.medias.length - 1;
        return;
      }
      currentMediaKey.value -= 1;
    };
    const handlePreviewRightBtn = () => {
      if (props.medias.length === 0) return;
      if (currentMediaKey.value + 1 > props.medias.length - 1) {
        currentMediaKey.value = 0;
        return;
      }
      currentMediaKey.value += 1;
    };

    return () => (
      <el-dialog
        v-model={props.dialog}
        destroyOnClose
        onClose={() => ctx.emit('update:dialog', false)}>
        <div class="preview-container">
          {props.medias?.length > 1 && (
            <>
              <div
                class="preview-action-btn preview-action-left"
                onClick={handlePreviewLeftBtn}>
                <i class="el-icon-arrow-left" />
              </div>
              <div
                class="preview-action-btn preview-action-right"
                onClick={handlePreviewRightBtn}>
                <i class="el-icon-arrow-right" />
              </div>
            </>
          )}
          {currentMedia.value.type === 'image' ? (
            <img src={BaseMediaUrl + currentMedia.value?.url} />
          ) : (
            <video controls src={BaseMediaUrl + currentMedia.value?.url} />
          )}
        </div>
      </el-dialog>
    );
  },
});
