import useMainStore from '@/store/useMainStore';
import {
  createRouter,
  createWebHashHistory,
  RouteLocation,
  RouteRecordRaw,
} from 'vue-router';
import { LOGIN_URL } from '@/utils/constant';
import { api_gettokenByTicket } from '@/service/login';
// import NProgress from 'nprogress';

const BaseLayout = () =>
  import(/* webpackChunkName: "BaseLayout" */ '@/layout/BaseLayout');
const ManagementLayout = () =>
  import(
    /* webpackChunkName: "ManagementLayout" */ '@/layout/ManagementLayout'
  );

const routes: RouteRecordRaw[] = [
  {
    path: '/',
    name: 'incident-management',
    component: BaseLayout,
    redirect: '/emergencyDisposal',
    children: [
      {
        path: '/emergencyDisposal',
        component: () =>
          import(/* webpackChunkName: "home.page" */ '@/views/HomePage'),
        name: '应急处置',
        meta: { title: '应急处置', iconName: 'TableOutlined' },
      },
      {
        path: '/status/:status/detail',
        component: () => import('@/views/IncidentManagementDetail'),
      },
      {
        path: '/status/:status/detaillite',
        component: () => import('@/views/IncidentManagementDetailLite'),
      },
      {
        path: '/status/:status/report',
        component: () => import('@/views/IncidentManagementReport'),
      },
      {
        path: '/warehouse/detail',
        component: () => import('@/views/Warehouse/index.vue'),
      },
      {
        path: '/warehouse/detail1',
        component: () => import('@/views/WarehouseDetail/index.vue'),
      },
      {
        path: '/warehouse/detailgoods',
        component: () => import('@/views/WarehouseDetailGoods/index.vue'),
      },
      {
        path: '/warehouse/edit',
        component: () => import('@/views/WarehouseEdit/index.vue'),
      },
      {
        path: '/warehouse/list',
        component: () => import('@/views/WarehouseList/index.vue'),
      },
      {
        path: '/warehouse/all',
        component: () => import('@/views/WarehouseListRead/index.vue'),
      },
      {
        path: '/warehouse/search',
        component: () => import('@/views/WarehouseSearch/index.vue'),
      },
      {
        path: '/chemical/search',
        component: () => import('@/views/WHPSearch/index.vue'),
      },
      {
        path: '/chemical/list',
        component: () => import('@/views/WHPList/index.vue'),
      },
      {
        path: '/chemical/detail',
        component: () => import('@/views/WHPDetail/index.vue'),
      },
    ],
  },
  {
    path: '/404',
    name: 'Global404',
    meta: { title: '页面不见啦.' },
    component: () => import(/* webpackChunkName: "404" */ '@/views/About'),
  },

  {
    path: '/:pathMatch(.*)*',
    name: 'All',
    redirect: (to: RouteLocation) => {
      return { path: '/404', query: { from: to.path } };
    },
  },
];

const router = createRouter({
  history: createWebHashHistory(),
  routes,
  scrollBehavior(to, from, savedPosition) {
    // 始终滚动到顶部
    return { top: 0 };
  },
});

router.beforeEach(() => {
  // NProgress.start();
  const main = useMainStore();
  main.clearReqToken();
});
router.afterEach((to) => {
  // NProgress.done();
  document!.title = to.meta.title
    ? to?.meta?.title + ' - 交通运输应急指挥系统'
    : '交通运输应急指挥系统';
  console.log(router.currentRoute.value.query);


  var route = router.currentRoute.value;
  var islogin = false;
    //判断url是否含有ticket
  if (route.query.ticket != undefined && route.query.ticket != null) {
    //存在ticket 根据ticket获取token 并保存清除ticket
    api_gettokenByTicket((route.query.ticket as string) ?? '').then(
      (res) => {
         console.log(res);
        window.localStorage.setItem('userdata', JSON.stringify(res.data));
        let newQuery = JSON.parse(JSON.stringify(route.query)); // 深拷贝
        delete newQuery.ticket;
        router.replace({ query: newQuery });
        setTimeout(() => { 
          location.reload();
        },100)
      }
    );
  } else {
    let userinfojson = window.localStorage.getItem('userdata');
    if (userinfojson != undefined || userinfojson != null) {
      islogin = true;
    }
    if (!islogin) {
      window.location.href = LOGIN_URL;
    }
  }
});

export default router;
