import {
  getIncidentList,
  putbackLog,
  getIncidentItem,
  GetIncidentListParams,
  IncidentItemDetail,
  IncidentListResponse,
  IncidentItem,
  putIncidentItem,
  postIncidentItem,
  IncidentProcessParam,
  addIncidentProcess,
  IncidentPlanTaskParam,
  addIncidentPlanTask,
  deleteIncidentTask,
} from '@/api/incident';
import {Toast} from 'vant';
// import { ElMessage } from 'element-plus';
import { defineStore } from 'pinia';

var ElMessage = Toast; 

export interface IncidentStateType {
  incidents: IncidentListResponse;
  loading: boolean;
  incidentDetail: IncidentItemDetail;
}

export interface IncidentActionsType {
  toggleLoading(): void;
  getIncidentList(params: GetIncidentListParams): void;
  getIncidentItem(id: number | string): void;
  putIncidentItem(params: IncidentItem): Promise<boolean | null | undefined>;
  postIncidentItem(params: IncidentItem): Promise<boolean | null | undefined>;
  addIncidentProcess(
    params: IncidentProcessParam,
  ): Promise<boolean | null | undefined>;
  addIncidentPlanTask(
    params: IncidentPlanTaskParam,
  ): Promise<boolean | null | undefined>;
  deleteIncidentTask(id: string): Promise<boolean | null | undefined>;
  putbackLog(taskid:string):void;
}

export default defineStore<
  'incident',
  IncidentStateType,
  {},
  IncidentActionsType
>('incident', {
  state: () => ({
    incidents: {
      rows: [],
      total: 0,
    },
    incidentDetail: {
      baseInfo: {},
      process: [],
      task: [],
    },
    loading: false,
  }),
  actions: {
    toggleLoading() {
      this.loading = !this.loading;
    },
    async getIncidentList(params) {
      try {
        this.toggleLoading();
        this.incidents = await getIncidentList(params);
        // this.incidents = {};
      } catch (w) { 
        this.toggleLoading();
      } finally {
        this.toggleLoading();
      }
    },
    async getIncidentItem(id) {
      try {
        this.toggleLoading();
        const { data } = await getIncidentItem(id);
        this.incidentDetail = data;
        // this.incidentDetail = {};
      } catch (w) {
        this.toggleLoading();
      } finally {
        this.toggleLoading();
      }
    },
    async putbackLog(taskid) {
      try {
        this.toggleLoading();
        await putbackLog(JSON.stringify({ taskId: taskid }));
        ElMessage.success({ message: '成功' });
        return true;
      } catch {
        ElMessage.fail({ message: '失败！' });
      } finally {
        this.toggleLoading();
      }
    },

    async postIncidentItem(params) {
      try {
        this.toggleLoading();
        await postIncidentItem(params);
        ElMessage.success({ message: '新增成功' });
        return true;
      } catch (E) {
        console.log(E)
        ElMessage.fail({ message: E+"" });
      } finally {
        this.toggleLoading();
      }
    },
    /** 修改事件状态 */
    /**  */
    async putIncidentItem(params) {
      try {
        this.toggleLoading();
        await putIncidentItem(params);
        if (params.madinDept || params.assistDept) {
          ElMessage.success({ message: `派发成功` });
          return true;
        }
        ElMessage.success({ message: '修改成功' });
        return true;
      } catch {
        ElMessage.fail({ message: '修改失败' });
      } finally {
        this.toggleLoading();
      }
    },
    /** 添加处置过程 */
    async addIncidentProcess(params) {
      try {
        this.toggleLoading();
        await addIncidentProcess(params);
        ElMessage.success({ message: '添加成功' });
        return true;
      } catch {
        ElMessage.fail({ message: '添加失败' });
      } finally {
        this.toggleLoading();
      }
    },
    /** 处置方案 */
    async addIncidentPlanTask(params) {
      try {
        this.toggleLoading();
        await addIncidentPlanTask(params);
        ElMessage.success({ message: '添加成功' });
        return true;
      } catch {
        ElMessage.fail({ message: '添加失败' });
      } finally {
        this.toggleLoading();
      }
    },
    async deleteIncidentTask(params) {
      try {
        this.toggleLoading();
        await deleteIncidentTask(params);
        ElMessage.success({ message: '删除成功' });
        return true;
      } catch {
        ElMessage.fail({ message: '删除失败' });
      } finally {
        this.toggleLoading();
      }
    },
  },
});
